### Sharing

Glyphs can stream the current Edit View to a second display such as an iPhone, iPad, or iPod Touch.
Choose “Enable External Preview” and download the _Glyphs Viewer_ app from the App Store or search for “Glyphs Viewer”.

The Mac running Glyphs and the iOS device need to be connected to the same network.
Open the iOS app and select the Mac with which to connect.
On the selected Mac, Glyphs will ask to confirm the connection.
Tap and hold anywhere on the app to return to its menu.

Glyphs Viewer displays the active Edit View.
Pinch to zoom with two fingers, and pan around with a single finger gesture.
Any change made to the glyphs is reflected immediately on the iOS device.

If the Glyphs Viewer app cannot find the Mac, make sure both the Mac and the iOS device are connected to the same wireless network.
If the problem persists, restart both devices and try again.
If they still cannot connect, try using a different network, or correct the router settings.
If the Mac and the iOS device communicate to the router with different wireless standards, Glyphs Viewer cannot connect to the Mac.
This issue can happen if the router is set up to simultaneously use multiple modulation standards (for example, g and n).
Setting the router to either 802.11 g only or 802.11 n only may help in such cases.
Once a connection has been established, a “Reset” button is added to the “Sharing” settings, which resets the list of trusted devices.